@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11852 2020-01-08 13:23:04Z Lavender $
+# $Id: __init__.py 11880 2020-01-19 11:50:00Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-01-08 22:23:04 +0900 (週三, 08 一月 2020) $
-# $Revision: 11852 $
+# $Date: 2020-01-19 19:50:00 +0800 (週日, 19 一月 2020) $
+# $Revision: 11880 $
 
 import os
 import sys
@@ -43,7 +43,11 @@ from Iuppiter.DjangoUtil import (extendInstalledApps,
 
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ugettext as _2
-from django.core.urlresolvers import reverse
+
+if DJANGO_VERSION <= 20000: # 2.0.0:
+    from django.core.urlresolvers import reverse
+else:
+    from django.urls import reverse
 
 from Iuno.Patch import patterns
 
@@ -696,6 +700,9 @@ def attachShopURLs(settings, urlpatterns):
         urlpatterns += patterns('',
             url(r'^(?P<name>.*)/preview/', 
                 views.SuccessResponseView2.as_view(), name='paymentPreview'),
+            url(r'^shop/orders/(?P<orderNumber>[\w-]*)/refund/', 
+                views.RefundView.as_view(),
+                name='refund'),
         )
     if ecpayEnable:
         urlpatterns += patterns('',
@@ -710,9 +717,6 @@ def attachShopURLs(settings, urlpatterns):
             url(r'^shop/ecpaylogistic/reply/', 
                 views.ECPayServerReplyView.as_view(),
                 name='ecpayLogisticReply'),
-            url(r'^shop/ecpaylogistic/(?P<orderNumber>[\w-]*)/return/', 
-                views.ECPayLogisticreturnView.as_view(),
-                name='ecpayLogisticReturn'),
         )
     if allpayEnable:
         urlpatterns += patterns('',
