@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11699 2019-09-05 08:41:06Z Lavender $
+# $Id: admin.py 11862 2020-01-14 12:01:35Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-09-05 16:41:06 +0800 (週四, 05 九月 2019) $
-# $Revision: 11699 $
+# $Date: 2020-01-14 20:01:35 +0800 (週二, 14 一月 2020) $
+# $Revision: 11862 $
 
 import os
 import datetime
@@ -33,7 +33,13 @@ from django.db import transaction
 from django.conf.urls import url
 from django.http import HttpResponseRedirect
 from django.contrib import messages
-from django.core.urlresolvers import reverse
+
+from Iuppiter.DjangoUtil import DJANGO_VERSION
+
+if DJANGO_VERSION <= 20000: # 2.0.0:
+    from django.core.urlresolvers import reverse
+else:
+    from django.urls import reverse
 
 # 介面拖拉上傳
 
